@@ -13,6 +13,13 @@ type Coordinates struct {
 	FileSystemID string `json:"layerID,omitempty" cyclonedx:"layerID"` // An ID representing the filesystem. For container images, this is a layer digest. For directories or a root filesystem, this is blank.
 }
 
+func NewCoordinates(realPath, fsID string) Coordinates {
+	return Coordinates{
+		RealPath:     realPath,
+		FileSystemID: fsID,
+	}
+}
+
 func (c Coordinates) ID() artifact.ID {
 	f, err := artifact.IDByHash(c)
 	if err != nil {
