@@ -4,6 +4,7 @@
 package fileresolver
 
 import (
+	"context"
 	"io"
 	"io/fs"
 	"os"
@@ -17,6 +18,7 @@ import (
 	"github.com/scylladb/go-set/strset"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"go.uber.org/goleak"
 
 	stereoscopeFile "github.com/anchore/stereoscope/pkg/file"
 	"github.com/anchore/syft/syft/file"
@@ -65,13 +67,13 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 	t.Cleanup(cleanup)
 
 	cases := []struct {
-		name                string
-		cwd                 string
-		root                string
-		base                string
-		input               string
-		expectedRealPath    string
-		expectedVirtualPath string // note: if empty it will be assumed to match the expectedRealPath
+		name               string
+		cwd                string
+		root               string
+		base               string
+		input              string
+		expectedRealPath   string
+		expectedAccessPath string // note: if empty it will be assumed to match the expectedRealPath
 	}{
 		{
 			name:             "relative root, relative request, direct",
@@ -139,7 +141,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "path/to/the/file.txt",
-			expectedVirtualPath: "path/to/the/file.txt",
+			expectedAccessPath: "path/to/the/file.txt",
 		},
 		{
 			name:             "abs root, relative request, direct, cwd within symlink root",
@@ -159,7 +161,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "path/to/the/file.txt",
-			expectedVirtualPath: "path/to/the/file.txt",
+			expectedAccessPath: "path/to/the/file.txt",
 		},
 		{
 			name:             "abs root, abs request, direct, cwd within symlink root",
@@ -180,7 +182,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath: "to/the/file.txt",
-			expectedVirtualPath: "to/the/file.txt",
+			expectedAccessPath: "to/the/file.txt",
 		},
 		{
 			name:             "abs root, relative nested request, direct, cwd within symlink root",
@@ -200,7 +202,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath: "to/the/file.txt",
-			expectedVirtualPath: "to/the/file.txt",
+			expectedAccessPath: "to/the/file.txt",
 		},
 		{
 			name:             "abs root, abs nested request, direct, cwd within symlink root",
@@ -221,7 +223,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "path/to/the/file.txt",
-			expectedVirtualPath: "path/to/the/file.txt",
+			expectedAccessPath: "path/to/the/file.txt",
 		},
 		{
 			name:             "abs root, relative request, direct, cwd within (double) symlink root",
@@ -241,7 +243,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "path/to/the/file.txt",
-			expectedVirtualPath: "path/to/the/file.txt",
+			expectedAccessPath: "path/to/the/file.txt",
 		},
 		{
 			name:             "abs root, abs request, direct, cwd within (double) symlink root",
@@ -262,7 +264,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "to/the/file.txt",
-			expectedVirtualPath: "to/the/file.txt",
+			expectedAccessPath: "to/the/file.txt",
 		},
 		{
 			name:             "abs root, relative nested request, direct, cwd within (double) symlink root",
@@ -282,7 +284,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "to/the/file.txt",
-			expectedVirtualPath: "to/the/file.txt",
+			expectedAccessPath: "to/the/file.txt",
 		},
 		{
 			name:             "abs root, abs nested request, direct, cwd within (double) symlink root",
@@ -303,7 +305,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "to/the/file.txt",
-			expectedVirtualPath: "to/the/file.txt",
+			expectedAccessPath: "to/the/file.txt",
 		},
 		{
 			name:             "abs root, relative nested request, direct, cwd deep within (double) symlink root",
@@ -323,7 +325,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			// outside the root.
 			expectedRealPath: filepath.Join(absolute, "path/to/the/file.txt"),
 			//expectedRealPath:    "to/the/file.txt",
-			expectedVirtualPath: "to/the/file.txt",
+			expectedAccessPath: "to/the/file.txt",
 		},
 		{
 			name:             "abs root, abs nested request, direct, cwd deep within (double) symlink root",
@@ -334,163 +336,163 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 		},
 		// link to outside of root cases...
 		{
-			name:                "relative root, relative request, abs indirect (outside of root)",
-			root:                filepath.Join(relative, "path"),
-			input:               "to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "relative root, relative request, abs indirect (outside of root)",
+			root:               filepath.Join(relative, "path"),
+			input:              "to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "abs root, relative request, abs indirect (outside of root)",
-			root:                filepath.Join(absolute, "path"),
-			input:               "to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "abs root, relative request, abs indirect (outside of root)",
+			root:               filepath.Join(absolute, "path"),
+			input:              "to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "relative root, abs request, abs indirect (outside of root)",
-			root:                filepath.Join(relative, "path"),
-			input:               "/to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "relative root, abs request, abs indirect (outside of root)",
+			root:               filepath.Join(relative, "path"),
+			input:              "/to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "abs root, abs request, abs indirect (outside of root)",
-			root:                filepath.Join(absolute, "path"),
-			input:               "/to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "abs root, abs request, abs indirect (outside of root)",
+			root:               filepath.Join(absolute, "path"),
+			input:              "/to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "relative root, relative request, relative indirect (outside of root)",
-			root:                filepath.Join(relative, "path"),
-			input:               "to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "relative root, relative request, relative indirect (outside of root)",
+			root:               filepath.Join(relative, "path"),
+			input:              "to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "abs root, relative request, relative indirect (outside of root)",
-			root:                filepath.Join(absolute, "path"),
-			input:               "to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "abs root, relative request, relative indirect (outside of root)",
+			root:               filepath.Join(absolute, "path"),
+			input:              "to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "relative root, abs request, relative indirect (outside of root)",
-			root:                filepath.Join(relative, "path"),
-			input:               "/to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "relative root, abs request, relative indirect (outside of root)",
+			root:               filepath.Join(relative, "path"),
+			input:              "/to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "abs root, abs request, relative indirect (outside of root)",
-			root:                filepath.Join(absolute, "path"),
-			input:               "/to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "abs root, abs request, relative indirect (outside of root)",
+			root:               filepath.Join(absolute, "path"),
+			input:              "/to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		// link to outside of root cases... cwd within symlink root
 		{
-			name:                "relative root, relative request, abs indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                "path",
-			input:               "to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "relative root, relative request, abs indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               "path",
+			input:              "to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "abs root, relative request, abs indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                filepath.Join(absolute, "path"),
-			input:               "to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "abs root, relative request, abs indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               filepath.Join(absolute, "path"),
+			input:              "to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "relative root, abs request, abs indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                "path",
-			input:               "/to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "relative root, abs request, abs indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               "path",
+			input:              "/to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "abs root, abs request, abs indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                filepath.Join(absolute, "path"),
-			input:               "/to/the/abs-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/abs-outside.txt",
+			name:               "abs root, abs request, abs indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               filepath.Join(absolute, "path"),
+			input:              "/to/the/abs-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/abs-outside.txt",
 		},
 		{
-			name:                "relative root, relative request, relative indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                "path",
-			input:               "to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "relative root, relative request, relative indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               "path",
+			input:              "to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "abs root, relative request, relative indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                filepath.Join(absolute, "path"),
-			input:               "to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "abs root, relative request, relative indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               filepath.Join(absolute, "path"),
+			input:              "to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "relative root, abs request, relative indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                "path",
-			input:               "/to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "relative root, abs request, relative indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               "path",
+			input:              "/to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "abs root, abs request, relative indirect (outside of root), cwd within symlink root",
-			cwd:                 relativeViaLink,
-			root:                filepath.Join(absolute, "path"),
-			input:               "/to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "abs root, abs request, relative indirect (outside of root), cwd within symlink root",
+			cwd:                relativeViaLink,
+			root:               filepath.Join(absolute, "path"),
+			input:              "/to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "relative root, relative request, relative indirect (outside of root), cwd within DOUBLE symlink root",
-			cwd:                 relativeViaDoubleLink,
-			root:                "path",
-			input:               "to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "relative root, relative request, relative indirect (outside of root), cwd within DOUBLE symlink root",
+			cwd:                relativeViaDoubleLink,
+			root:               "path",
+			input:              "to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "abs root, relative request, relative indirect (outside of root), cwd within DOUBLE symlink root",
-			cwd:                 relativeViaDoubleLink,
-			root:                filepath.Join(absolute, "path"),
-			input:               "to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "abs root, relative request, relative indirect (outside of root), cwd within DOUBLE symlink root",
+			cwd:                relativeViaDoubleLink,
+			root:               filepath.Join(absolute, "path"),
+			input:              "to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "relative root, abs request, relative indirect (outside of root), cwd within DOUBLE symlink root",
-			cwd:                 relativeViaDoubleLink,
-			root:                "path",
-			input:               "/to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "relative root, abs request, relative indirect (outside of root), cwd within DOUBLE symlink root",
+			cwd:                relativeViaDoubleLink,
+			root:               "path",
+			input:              "/to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 		{
-			name:                "abs root, abs request, relative indirect (outside of root), cwd within DOUBLE symlink root",
-			cwd:                 relativeViaDoubleLink,
-			root:                filepath.Join(absolute, "path"),
-			input:               "/to/the/rel-outside.txt",
-			expectedRealPath:    filepath.Join(absolute, "/somewhere/outside.txt"),
-			expectedVirtualPath: "to/the/rel-outside.txt",
+			name:               "abs root, abs request, relative indirect (outside of root), cwd within DOUBLE symlink root",
+			cwd:                relativeViaDoubleLink,
+			root:               filepath.Join(absolute, "path"),
+			input:              "/to/the/rel-outside.txt",
+			expectedRealPath:   filepath.Join(absolute, "/somewhere/outside.txt"),
+			expectedAccessPath: "to/the/rel-outside.txt",
 		},
 	}
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
-			if c.expectedVirtualPath == "" {
-				c.expectedVirtualPath = c.expectedRealPath
+			if c.expectedAccessPath == "" {
+				c.expectedAccessPath = c.expectedRealPath
 			}
 
 			// we need to mimic a shell, otherwise we won't get a path within a symlink
@@ -515,7 +517,7 @@ func TestDirectoryResolver_FilesByPath_request_response(t *testing.T) {
 			}
 			require.Len(t, refs, 1)
 			assert.Equal(t, c.expectedRealPath, refs[0].RealPath, "real path different")
-			assert.Equal(t, c.expectedVirtualPath, refs[0].VirtualPath, "virtual path different")
+			assert.Equal(t, c.expectedAccessPath, refs[0].AccessPath, "virtual path different")
 		})
 	}
 }
@@ -916,7 +918,7 @@ func Test_isUnallowableFileType(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			assert.Equal(t, test.expected, disallowByFileType("dont/care", test.info, nil))
+			assert.Equal(t, test.expected, disallowByFileType("", "dont/care", test.info, nil))
 		})
 	}
 }
@@ -961,14 +963,14 @@ func Test_IndexingNestedSymLinks(t *testing.T) {
 	require.NoError(t, err)
 	require.Len(t, locations, 1)
 	assert.Equal(t, "readme", locations[0].RealPath)
-	assert.Equal(t, "link_to_new_readme", locations[0].VirtualPath)
+	assert.Equal(t, "link_to_new_readme", locations[0].AccessPath)
 
 	// check that we can access the same file via 2 symlinks
 	locations, err = resolver.FilesByPath("./link_to_link_to_new_readme")
 	require.NoError(t, err)
 	require.Len(t, locations, 1)
 	assert.Equal(t, "readme", locations[0].RealPath)
-	assert.Equal(t, "link_to_link_to_new_readme", locations[0].VirtualPath)
+	assert.Equal(t, "link_to_link_to_new_readme", locations[0].AccessPath)
 
 	// check that we can access the same file via 2 symlinks
 	locations, err = resolver.FilesByGlob("**/link_*")
@@ -976,7 +978,7 @@ func Test_IndexingNestedSymLinks(t *testing.T) {
 	require.Len(t, locations, 1) // you would think this is 2, however, they point to the same file, and glob only returns unique files
 
 	// returned locations can be in any order
-	expectedVirtualPaths := []string{
+	expectedAccessPaths := []string{
 		"link_to_link_to_new_readme",
 		//"link_to_new_readme", // we filter out this one because the first symlink resolves to the same file
 	}
@@ -986,18 +988,18 @@ func Test_IndexingNestedSymLinks(t *testing.T) {
 	}
 
 	actualRealPaths := strset.New()
-	actualVirtualPaths := strset.New()
+	actualAccessPaths := strset.New()
 	for _, a := range locations {
-		actualVirtualPaths.Add(a.VirtualPath)
+		actualAccessPaths.Add(a.AccessPath)
 		actualRealPaths.Add(a.RealPath)
 	}
 
-	assert.ElementsMatch(t, expectedVirtualPaths, actualVirtualPaths.List())
+	assert.ElementsMatch(t, expectedAccessPaths, actualAccessPaths.List())
 	assert.ElementsMatch(t, expectedRealPaths, actualRealPaths.List())
 }
 
 func Test_IndexingNestedSymLinks_ignoredIndexes(t *testing.T) {
-	filterFn := func(path string, _ os.FileInfo, _ error) error {
+	filterFn := func(_, path string, _ os.FileInfo, _ error) error {
 		if strings.HasSuffix(path, string(filepath.Separator)+"readme") {
 			return ErrSkipPath
 		}
@@ -1106,47 +1108,6 @@ func Test_directoryResolver_FileContentsByLocation(t *testing.T) {
 	}
 }
 
-func Test_isUnixSystemRuntimePath(t *testing.T) {
-	tests := []struct {
-		path     string
-		expected error
-	}{
-		{
-			path: "proc/place",
-		},
-		{
-			path:     "/proc/place",
-			expected: fs.SkipDir,
-		},
-		{
-			path:     "/proc",
-			expected: fs.SkipDir,
-		},
-		{
-			path: "/pro/c",
-		},
-		{
-			path: "/pro",
-		},
-		{
-			path:     "/dev",
-			expected: fs.SkipDir,
-		},
-		{
-			path:     "/sys",
-			expected: fs.SkipDir,
-		},
-		{
-			path: "/something/sys",
-		},
-	}
-	for _, test := range tests {
-		t.Run(test.path, func(t *testing.T) {
-			assert.Equal(t, test.expected, disallowUnixSystemRuntimePath(test.path, nil, nil))
-		})
-	}
-}
-
 func Test_SymlinkLoopWithGlobsShouldResolve(t *testing.T) {
 	test := func(t *testing.T) {
 		resolver, err := NewFromDirectory("./test-fixtures/symlinks-loop", "")
@@ -1380,7 +1341,7 @@ func TestDirectoryResolver_DoNotAddVirtualPathsToTree(t *testing.T) {
 	require.NoError(t, err)
 
 	var allRealPaths []stereoscopeFile.Path
-	for l := range resolver.AllLocations() {
+	for l := range resolver.AllLocations(context.Background()) {
 		allRealPaths = append(allRealPaths, stereoscopeFile.Path(l.RealPath))
 	}
 	pathSet := stereoscopeFile.NewPathSet(allRealPaths...)
@@ -1398,11 +1359,14 @@ func TestDirectoryResolver_DoNotAddVirtualPathsToTree(t *testing.T) {
 }
 
 func TestDirectoryResolver_FilesContents_errorOnDirRequest(t *testing.T) {
+	defer goleak.VerifyNone(t)
 	resolver, err := NewFromDirectory("./test-fixtures/system_paths", "")
 	assert.NoError(t, err)
 
 	var dirLoc *file.Location
-	for loc := range resolver.AllLocations() {
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+	for loc := range resolver.AllLocations(ctx) {
 		entry, err := resolver.index.Get(loc.Reference())
 		require.NoError(t, err)
 		if entry.Metadata.IsDir() {
@@ -1423,7 +1387,7 @@ func TestDirectoryResolver_AllLocations(t *testing.T) {
 	assert.NoError(t, err)
 
 	paths := strset.New()
-	for loc := range resolver.AllLocations() {
+	for loc := range resolver.AllLocations(context.Background()) {
 		if strings.HasPrefix(loc.RealPath, "/") {
 			// ignore outside the fixture root for now
 			continue
@@ -1449,3 +1413,14 @@ func TestDirectoryResolver_AllLocations(t *testing.T) {
 
 	assert.ElementsMatchf(t, expected, pathsList, "expected all paths to be indexed, but found different paths: \n%s", cmp.Diff(expected, paths.List()))
 }
+
+func TestAllLocationsDoesNotLeakGoRoutine(t *testing.T) {
+	defer goleak.VerifyNone(t)
+	resolver, err := NewFromDirectory("./test-fixtures/symlinks-from-image-symlinks-fixture", "")
+	require.NoError(t, err)
+	ctx, cancel := context.WithCancel(context.Background())
+	for range resolver.AllLocations(ctx) {
+		break
+	}
+	cancel()
+}
