@@ -1,11 +1,13 @@
 package dotnet
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"sort"
 
 	"github.com/anchore/syft/internal/log"
+	"github.com/anchore/syft/internal/relationship"
 	"github.com/anchore/syft/syft/artifact"
 	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
@@ -37,7 +39,7 @@ type dotnetDepsLibrary struct {
 }
 
 //nolint:funlen
-func parseDotnetDeps(_ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
+func parseDotnetDeps(_ context.Context, _ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	var pkgs []pkg.Package
 	var pkgMap = make(map[string]pkg.Package)
 	var relationships []artifact.Relationship
@@ -49,9 +51,9 @@ func parseDotnetDeps(_ file.Resolver, _ *generic.Environment, reader file.Locati
 		return nil, nil, fmt.Errorf("failed to parse deps.json file: %w", err)
 	}
 
-	rootName := getDepsJSONFilePrefix(reader.AccessPath())
+	rootName := getDepsJSONFilePrefix(reader.Path())
 	if rootName == "" {
-		return nil, nil, fmt.Errorf("unable to determine root package name from deps.json file: %s", reader.AccessPath())
+		return nil, nil, fmt.Errorf("unable to determine root package name from deps.json file: %s", reader.Path())
 	}
 	var rootPkg *pkg.Package
 	for nameVersion, lib := range depsDoc.Libraries {
@@ -65,7 +67,7 @@ func parseDotnetDeps(_ file.Resolver, _ *generic.Environment, reader file.Locati
 		}
 	}
 	if rootPkg == nil {
-		return nil, nil, fmt.Errorf("unable to determine root package from deps.json file: %s", reader.AccessPath())
+		return nil, nil, fmt.Errorf("unable to determine root package from deps.json file: %s", reader.Path())
 	}
 	pkgs = append(pkgs, *rootPkg)
 	pkgMap[createNameAndVersion(rootPkg.Name, rootPkg.Version)] = *rootPkg
@@ -122,7 +124,7 @@ func parseDotnetDeps(_ file.Resolver, _ *generic.Environment, reader file.Locati
 	// sort the relationships for deterministic output
 	// TODO: ideally this would be replaced with artifact.SortRelationships when one exists and is type agnostic.
 	// this will only consider package-to-package relationships.
-	pkg.SortRelationships(relationships)
+	relationship.Sort(relationships)
 
 	return pkgs, relationships, nil
 }
