@@ -1,6 +1,7 @@
 package javascript
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -14,9 +15,6 @@ import (
 	"github.com/anchore/syft/syft/pkg/cataloger/generic"
 )
 
-// integrity check
-var _ generic.Parser = parsePackageLock
-
 // packageLock represents a JavaScript package.lock json file
 type packageLock struct {
 	Requires        bool `json:"requires"`
@@ -43,11 +41,21 @@ type lockPackage struct {
 // packageLockLicense
 type packageLockLicense []string
 
+type genericPackageLockAdapter struct {
+	cfg CatalogerConfig
+}
+
+func newGenericPackageLockAdapter(cfg CatalogerConfig) genericPackageLockAdapter {
+	return genericPackageLockAdapter{
+		cfg: cfg,
+	}
+}
+
 // parsePackageLock parses a package-lock.json and returns the discovered JavaScript packages.
-func parsePackageLock(resolver file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
+func (a genericPackageLockAdapter) parsePackageLock(_ context.Context, resolver file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	// in the case we find package-lock.json files in the node_modules directories, skip those
 	// as the whole purpose of the lock file is for the specific dependencies of the root project
-	if pathContainsNodeModulesDirectory(reader.AccessPath()) {
+	if pathContainsNodeModulesDirectory(reader.Path()) {
 		return nil, nil, nil
 	}
 
@@ -65,7 +73,7 @@ func parsePackageLock(resolver file.Resolver, _ *generic.Environment, reader fil
 
 	if lock.LockfileVersion == 1 {
 		for name, pkgMeta := range lock.Dependencies {
-			pkgs = append(pkgs, newPackageLockV1Package(resolver, reader.Location, name, pkgMeta))
+			pkgs = append(pkgs, newPackageLockV1Package(a.cfg, resolver, reader.Location, name, pkgMeta))
 		}
 	}
 
@@ -85,7 +93,7 @@ func parsePackageLock(resolver file.Resolver, _ *generic.Environment, reader fil
 
 			pkgs = append(
 				pkgs,
-				newPackageLockV2Package(resolver, reader.Location, getNameFromPath(name), pkgMeta),
+				newPackageLockV2Package(a.cfg, resolver, reader.Location, getNameFromPath(name), pkgMeta),
 			)
 		}
 	}
