@@ -1,6 +1,7 @@
 package php
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -16,19 +17,24 @@ var _ generic.Parser = parseComposerLock
 
 // Note: composer version 2 introduced a new structure for the installed.json file, so we support both
 type installedJSONComposerV2 struct {
-	Packages []parsedData `json:"packages"`
+	Packages []parsedInstalledData `json:"packages"`
+}
+
+type parsedInstalledData struct {
+	License []string `json:"license"`
+	pkg.PhpComposerInstalledEntry
 }
 
 func (w *installedJSONComposerV2) UnmarshalJSON(data []byte) error {
 	type compv2 struct {
-		Packages []parsedData `json:"packages"`
+		Packages []parsedInstalledData `json:"packages"`
 	}
 	compv2er := new(compv2)
 	err := json.Unmarshal(data, &compv2er)
 	if err != nil {
 		// If we had an err	or, we may be dealing with a composer v.1 installed.json
 		// which should be all arrays
-		var packages []parsedData
+		var packages []parsedInstalledData
 		err := json.Unmarshal(data, &packages)
 		if err != nil {
 			return err
@@ -41,7 +47,7 @@ func (w *installedJSONComposerV2) UnmarshalJSON(data []byte) error {
 }
 
 // parseInstalledJSON is a parser function for Composer.lock contents, returning "Default" php packages discovered.
-func parseInstalledJSON(_ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
+func parseInstalledJSON(_ context.Context, _ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	var pkgs []pkg.Package
 	dec := json.NewDecoder(reader)
 
@@ -52,11 +58,12 @@ func parseInstalledJSON(_ file.Resolver, _ *generic.Environment, reader file.Loc
 		} else if err != nil {
 			return nil, nil, fmt.Errorf("failed to parse installed.json file: %w", err)
 		}
-		for _, pkgMeta := range lock.Packages {
+		for _, pd := range lock.Packages {
 			pkgs = append(
 				pkgs,
-				newComposerLockPackage(pkgMeta,
-					reader.Location.WithAnnotation(pkg.EvidenceAnnotationKey, pkg.PrimaryEvidenceAnnotation),
+				newComposerInstalledPackage(
+					pd,
+					reader.Location,
 				),
 			)
 		}
