@@ -4,6 +4,8 @@ import (
 	"fmt"
 
 	"github.com/anchore/packageurl-go"
+	"github.com/anchore/syft/internal/licenses"
+	"github.com/anchore/syft/internal/log"
 	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
 )
@@ -23,7 +25,7 @@ func newPackageForIndex(name, version string, locations ...file.Location) pkg.Pa
 	return p
 }
 
-func newPackageForIndexWithMetadata(name, version string, metadata pkg.PythonPipfileLockEntry, locations ...file.Location) pkg.Package {
+func newPackageForIndexWithMetadata(name, version string, metadata interface{}, locations ...file.Location) pkg.Package {
 	p := pkg.Package{
 		Name:      name,
 		Version:   version,
@@ -55,13 +57,42 @@ func newPackageForRequirementsWithMetadata(name, version string, metadata pkg.Py
 	return p
 }
 
-func newPackageForPackage(m parsedData, sources ...file.Location) pkg.Package {
+func newPackageForPackage(resolver file.Resolver, m parsedData, sources ...file.Location) pkg.Package {
+	var licenseSet pkg.LicenseSet
+
+	switch {
+	case m.LicenseExpression != "":
+		licenseSet = pkg.NewLicenseSet(pkg.NewLicensesFromLocation(m.LicenseLocation, m.LicenseExpression)...)
+	case m.Licenses != "":
+		licenseSet = pkg.NewLicenseSet(pkg.NewLicensesFromLocation(m.LicenseLocation, m.Licenses)...)
+	case m.LicenseLocation.Path() != "":
+		// If we have a license file then resolve and parse it
+		found, err := resolver.FilesByPath(m.LicenseLocation.Path())
+		if err != nil {
+			log.WithFields("error", err).Tracef("unable to resolve python license path %s", m.LicenseLocation.Path())
+		}
+		if len(found) > 0 {
+			metadataContents, err := resolver.FileContentsByLocation(found[0])
+			if err == nil {
+				parsed, err := licenses.Parse(metadataContents, m.LicenseLocation)
+				if err != nil {
+					log.WithFields("error", err).Tracef("unable to parse a license from the file in %s", m.LicenseLocation.Path())
+				}
+				if len(parsed) > 0 {
+					licenseSet = pkg.NewLicenseSet(parsed...)
+				}
+			} else {
+				log.WithFields("error", err).Tracef("unable to read file contents at %s", m.LicenseLocation.Path())
+			}
+		}
+	}
+
 	p := pkg.Package{
 		Name:      m.Name,
 		Version:   m.Version,
 		PURL:      packageURL(m.Name, m.Version, &m.PythonPackage),
 		Locations: file.NewLocationSet(sources...),
-		Licenses:  pkg.NewLicenseSet(pkg.NewLicensesFromLocation(m.LicenseLocation, m.Licenses)...),
+		Licenses:  licenseSet,
 		Language:  pkg.Python,
 		Type:      pkg.PythonPkg,
 		Metadata:  m.PythonPackage,
