@@ -9,16 +9,15 @@ import (
 )
 
 // Pkg returns the standard `pkg.Package` representation of the package referenced within the Cargo.lock metadata.
-func newPackageFromCargoMetadata(m pkg.CargoPackageMetadata, locations ...file.Location) pkg.Package {
+func newPackageFromCargoMetadata(m pkg.RustCargoLockEntry, locations ...file.Location) pkg.Package {
 	p := pkg.Package{
-		Name:         m.Name,
-		Version:      m.Version,
-		Locations:    file.NewLocationSet(locations...),
-		PURL:         packageURL(m.Name, m.Version),
-		Language:     pkg.Rust,
-		Type:         pkg.RustPkg,
-		MetadataType: pkg.RustCargoPackageMetadataType,
-		Metadata:     m,
+		Name:      m.Name,
+		Version:   m.Version,
+		Locations: file.NewLocationSet(locations...),
+		PURL:      packageURL(m.Name, m.Version),
+		Language:  pkg.Rust,
+		Type:      pkg.RustPkg,
+		Metadata:  m,
 	}
 
 	p.SetID()
@@ -42,14 +41,13 @@ func newPackagesFromAudit(location file.Location, versionInfo rustaudit.VersionI
 
 func newPackageFromAudit(dep *rustaudit.Package, locations ...file.Location) pkg.Package {
 	p := pkg.Package{
-		Name:         dep.Name,
-		Version:      dep.Version,
-		PURL:         packageURL(dep.Name, dep.Version),
-		Language:     pkg.Rust,
-		Type:         pkg.RustPkg,
-		Locations:    file.NewLocationSet(locations...),
-		MetadataType: pkg.RustCargoPackageMetadataType,
-		Metadata: pkg.CargoPackageMetadata{
+		Name:      dep.Name,
+		Version:   dep.Version,
+		PURL:      packageURL(dep.Name, dep.Version),
+		Language:  pkg.Rust,
+		Type:      pkg.RustPkg,
+		Locations: file.NewLocationSet(locations...),
+		Metadata: pkg.RustBinaryAuditEntry{
 			Name:    dep.Name,
 			Version: dep.Version,
 			Source:  dep.Source,
