@@ -14,15 +14,14 @@ func TestParseCargoLock(t *testing.T) {
 	locations := file.NewLocationSet(file.NewLocation(fixture))
 	expectedPkgs := []pkg.Package{
 		{
-			Name:         "ansi_term",
-			Version:      "0.12.1",
-			PURL:         "pkg:cargo/ansi_term@0.12.1",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "ansi_term",
+			Version:   "0.12.1",
+			PURL:      "pkg:cargo/ansi_term@0.12.1",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:     "ansi_term",
 				Version:  "0.12.1",
 				Source:   "registry+https://github.com/rust-lang/crates.io-index",
@@ -33,15 +32,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "matches",
-			Version:      "0.1.8",
-			PURL:         "pkg:cargo/matches@0.1.8",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "matches",
+			Version:   "0.1.8",
+			PURL:      "pkg:cargo/matches@0.1.8",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:         "matches",
 				Version:      "0.1.8",
 				Source:       "registry+https://github.com/rust-lang/crates.io-index",
@@ -50,15 +48,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "memchr",
-			Version:      "2.3.3",
-			PURL:         "pkg:cargo/memchr@2.3.3",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "memchr",
+			Version:   "2.3.3",
+			PURL:      "pkg:cargo/memchr@2.3.3",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:         "memchr",
 				Version:      "2.3.3",
 				Source:       "registry+https://github.com/rust-lang/crates.io-index",
@@ -67,15 +64,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "natord",
-			Version:      "1.0.9",
-			PURL:         "pkg:cargo/natord@1.0.9",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "natord",
+			Version:   "1.0.9",
+			PURL:      "pkg:cargo/natord@1.0.9",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:         "natord",
 				Version:      "1.0.9",
 				Source:       "registry+https://github.com/rust-lang/crates.io-index",
@@ -84,15 +80,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "nom",
-			Version:      "4.2.3",
-			PURL:         "pkg:cargo/nom@4.2.3",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "nom",
+			Version:   "4.2.3",
+			PURL:      "pkg:cargo/nom@4.2.3",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:     "nom",
 				Version:  "4.2.3",
 				Source:   "registry+https://github.com/rust-lang/crates.io-index",
@@ -104,15 +99,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "unicode-bidi",
-			Version:      "0.3.4",
-			PURL:         "pkg:cargo/unicode-bidi@0.3.4",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "unicode-bidi",
+			Version:   "0.3.4",
+			PURL:      "pkg:cargo/unicode-bidi@0.3.4",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:     "unicode-bidi",
 				Version:  "0.3.4",
 				Source:   "registry+https://github.com/rust-lang/crates.io-index",
@@ -123,15 +117,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "version_check",
-			Version:      "0.1.5",
-			PURL:         "pkg:cargo/version_check@0.1.5",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "version_check",
+			Version:   "0.1.5",
+			PURL:      "pkg:cargo/version_check@0.1.5",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:         "version_check",
 				Version:      "0.1.5",
 				Source:       "registry+https://github.com/rust-lang/crates.io-index",
@@ -140,15 +133,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "winapi",
-			Version:      "0.3.9",
-			PURL:         "pkg:cargo/winapi@0.3.9",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "winapi",
+			Version:   "0.3.9",
+			PURL:      "pkg:cargo/winapi@0.3.9",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:     "winapi",
 				Version:  "0.3.9",
 				Source:   "registry+https://github.com/rust-lang/crates.io-index",
@@ -160,15 +152,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "winapi-i686-pc-windows-gnu",
-			Version:      "0.4.0",
-			PURL:         "pkg:cargo/winapi-i686-pc-windows-gnu@0.4.0",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "winapi-i686-pc-windows-gnu",
+			Version:   "0.4.0",
+			PURL:      "pkg:cargo/winapi-i686-pc-windows-gnu@0.4.0",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:         "winapi-i686-pc-windows-gnu",
 				Version:      "0.4.0",
 				Source:       "registry+https://github.com/rust-lang/crates.io-index",
@@ -177,15 +168,14 @@ func TestParseCargoLock(t *testing.T) {
 			},
 		},
 		{
-			Name:         "winapi-x86_64-pc-windows-gnu",
-			Version:      "0.4.0",
-			PURL:         "pkg:cargo/winapi-x86_64-pc-windows-gnu@0.4.0",
-			Locations:    locations,
-			Language:     pkg.Rust,
-			Type:         pkg.RustPkg,
-			MetadataType: pkg.RustCargoPackageMetadataType,
-			Licenses:     pkg.NewLicenseSet(),
-			Metadata: pkg.CargoPackageMetadata{
+			Name:      "winapi-x86_64-pc-windows-gnu",
+			Version:   "0.4.0",
+			PURL:      "pkg:cargo/winapi-x86_64-pc-windows-gnu@0.4.0",
+			Locations: locations,
+			Language:  pkg.Rust,
+			Type:      pkg.RustPkg,
+			Licenses:  pkg.NewLicenseSet(),
+			Metadata: pkg.RustCargoLockEntry{
 				Name:         "winapi-x86_64-pc-windows-gnu",
 				Version:      "0.4.0",
 				Source:       "registry+https://github.com/rust-lang/crates.io-index",
