@@ -1,10 +1,9 @@
 package cli
 
 import (
-	"bufio"
 	"bytes"
+	"flag"
 	"fmt"
-	"io"
 	"math"
 	"os"
 	"os/exec"
@@ -16,33 +15,17 @@ import (
 	"testing"
 	"time"
 
-	"github.com/stretchr/testify/require"
-
 	"github.com/anchore/stereoscope/pkg/imagetest"
 )
 
-func runAndShow(t *testing.T, cmd *exec.Cmd) {
-	t.Helper()
+var showOutput = flag.Bool("show-output", false, "show stdout and stderr for failing tests")
 
-	stderr, err := cmd.StderrPipe()
-	require.NoErrorf(t, err, "could not get stderr: +v", err)
-
-	stdout, err := cmd.StdoutPipe()
-	require.NoErrorf(t, err, "could not get stdout: +v", err)
-
-	err = cmd.Start()
-	require.NoErrorf(t, err, "failed to start cmd: %+v", err)
-
-	show := func(label string, reader io.ReadCloser) {
-		scanner := bufio.NewScanner(reader)
-		scanner.Split(bufio.ScanLines)
-		for scanner.Scan() {
-			t.Logf("%s: %s", label, scanner.Text())
-		}
+func logOutputOnFailure(t testing.TB, cmd *exec.Cmd, stdout, stderr string) {
+	if t.Failed() && showOutput != nil && *showOutput {
+		t.Log("STDOUT:\n", stdout)
+		t.Log("STDERR:\n", stderr)
+		t.Log("COMMAND:", strings.Join(cmd.Args, " "))
 	}
-
-	show("out", stdout)
-	show("err", stderr)
 }
 
 func setupPKI(t *testing.T, pw string) func() {
